"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const web_ui_1 = __importDefault(require("@hypernetlabs/web-ui"));
const HypernetIFrameProxy_1 = __importDefault(require("../../implementations/proxy/HypernetIFrameProxy"));
class HypernetWebIntegration {
    constructor(iframeURL) {
        this.iframeURL = "http://localhost:5020";
        this.iframeURL = iframeURL || this.iframeURL;
        // Create a proxy connection to the iframe
        this.core = new HypernetIFrameProxy_1.default(this._prepareIFrameContainer(), this.iframeURL, "hypernet-core-iframe");
        this.core.onMerchantIFrameDisplayRequested.subscribe((merchantUrl) => {
            this.currentMerchantUrl = merchantUrl;
        });
        if (window.hypernetWebUIInstance) {
            this.webUIClient = window.hypernetWebUIInstance;
        }
        else {
            this.webUIClient = new web_ui_1.default(this.core);
        }
        this.core.onPrivateCredentialsRequested.subscribe(() => {
            this.webUIClient.renderPrivateKeysModal();
        });
    }
    getReady() {
        if (this.getReadyResult != null) {
            return this.getReadyResult;
        }
        this.getReadyResult = this.core
            .activate()
            .andThen(() => {
            return this.core.getEthereumAccounts();
        })
            .andThen((accounts) => this.core.initialize(accounts[0]))
            .map(() => {
            // This is for web ui to use if there is no core instance passed in web ui constructor
            window.hypernetCoreInstance = this.core;
            return this.core;
        });
        return this.getReadyResult;
    }
    // This class must be used as a singleton, this enforces that restriction.
    static getInstance() {
        if (HypernetWebIntegration.instance == null) {
            HypernetWebIntegration.instance = new HypernetWebIntegration();
        }
        return HypernetWebIntegration.instance;
    }
    displayMerchantIFrame(merchantUrl) {
        this.core.displayMerchantIFrame(merchantUrl);
    }
    closeMerchantIFrame(merchantUrl) {
        this.core.closeMerchantIFrame(merchantUrl);
    }
    _prepareIFrameContainer() {
        // Create a container element for the iframe proxy
        const iframeContainer = document.createElement("div");
        iframeContainer.id = "__hypernet-protocol-iframe-container__";
        // Add close modal icon to iframe container
        const closeButton = document.createElement("div");
        closeButton.id = "__hypernet-protocol-iframe-close-icon__";
        closeButton.innerHTML = `
      <img id="__hypernet-protocol-iframe-close-img__" src="https://res.cloudinary.com/dqueufbs7/image/upload/v1611371438/images/Close-512.png" width="20" />
    `;
        iframeContainer.appendChild(closeButton);
        // Add iframe modal style
        const style = document.createElement("style");
        style.appendChild(document.createTextNode(`
        iframe {
          position: absolute;
          display: none;
          border: none;
          width: 550px;
          height: 60%;
          min-height: 200px;
          background-color: white;
          top: 50%;
          left: 50%;
          box-shadow: 0px 4px 20px #000000;
          border-radius: 4px;
          transform: translate(-50%, -50%);
        }
        #__hypernet-protocol-iframe-container__ {
          position: absolute;
          display: none;
          top: 0;
          left: 0;
          height: 100%;
          width: 100%;
          background-color: rgba(0,0,0,0.6);
          z-index: 999999 !important;
        }
        #__hypernet-protocol-iframe-close-icon__ {
          z-index: 2;
          position: absolute;
          height: 60%;
          top: 50%;
          left: 50%;
          transform: translate(calc(-50% + 263px), -50%);
        }
        #__hypernet-protocol-iframe-close-img__{
          cursor: pointer;
        }
    `));
        document.head.appendChild(style);
        // Attach everything to the body
        document.body.appendChild(iframeContainer);
        const closeImg = document.getElementById("__hypernet-protocol-iframe-close-img__");
        closeImg === null || closeImg === void 0 ? void 0 : closeImg.addEventListener("click", (e) => {
            if (this.currentMerchantUrl != null) {
                this.core.closeMerchantIFrame(this.currentMerchantUrl);
                this.currentMerchantUrl = null;
            }
            iframeContainer.style.display = "none";
        }, false);
        return iframeContainer;
    }
}
exports.default = HypernetWebIntegration;
window.HypernetWebIntegration = HypernetWebIntegration;
//# sourceMappingURL=HypernetWebIntegration.js.map